==> ejc-supbid-api-3.0.1-20220210.123919-143-sources.jar: com/ejianc/business/supbid/notice/vo/SignVO.java <==
package com.ejianc.business.supbid.notice.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;


/**
 * 报名实体
 * 
 * @author generator
 * 
 */
@ApiModel("报名实体")
public class SignVO{
    private static final long serialVersionUID = 1L;

    @ApiModelProperty("返回前段用的主键")
    private java.lang.Long sId;
    @ApiModelProperty("主表主键")
    private java.lang.Long noticeId;
    @ApiModelProperty("供应商来源主键")
    private java.lang.String sourceSupplierId;
    @ApiModelProperty("招标信息主键")
    private java.lang.String sourceId;
    @ApiModelProperty("状态(0-已报名，1-待报价，2-洽商谈判，3-报价中，4-已定标，5-已淘汰)")
    private java.lang.Integer signStatus;
    @ApiModelProperty("淘汰原因")
    private java.lang.String outReason;
    @ApiModelProperty("报名联系人")
    private java.lang.Long signEmployeeId;
    @ApiModelProperty("报名联系人名称")
    private java.lang.String signEmployeeName;
    @ApiModelProperty("报名联系人电话")
    private java.lang.String signEmployeeMobile;
    @ApiModelProperty("发票说明")
    private java.lang.String invoiceNote;
    @ApiModelProperty("报名时间")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private java.util.Date signTime;
    @ApiModelProperty("报价时间")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private java.util.Date schemeTime;
    @ApiModelProperty("报名操作人")
    private java.lang.Long signId;
    @ApiModelProperty("报名操作人名称")
    private java.lang.String signName;
    @ApiModelProperty("报价操作人")
    private java.lang.Long schemeId;
    @ApiModelProperty("报价操作人名称")
    private java.lang.String schemeName;
    @ApiModelProperty("租户主键")
    private java.lang.Long tenantId;
    private List<Long> attachIds = new ArrayList();

    public List<Long> getAttachIds() {
        return attachIds;
    }

    public void setAttachIds(List<Long> attachIds) {
        this.attachIds = attachIds;
    }

    public Long getTenantId() {
        return tenantId;
    }

    public void setTenantId(Long tenantId) {
        this.tenantId = tenantId;
    }

    public Long getsId() {
        return sId;
    }

    public void setsId(Long sId) {
        this.sId = sId;
    }

    public String getSourceSupplierId() {
        return sourceSupplierId;
    }

    public void setSourceSupplierId(String sourceSupplierId) {
        this.sourceSupplierId = sourceSupplierId;
    }

    /**
     * 主表主键
     */
    public java.lang.Long getNoticeId() {
        return noticeId;
    }

    /**
     * 主表主键
     */
    public void setNoticeId(java.lang.Long noticeId) {
        this.noticeId = noticeId;
    }
    /**
     * 招标信息主键
     */
    public java.lang.String getSourceId() {
        return sourceId;
    }

    /**
     * 招标信息主键
     */
    public void setSourceId(java.lang.String sourceId) {
        this.sourceId = sourceId;
    }
    /**
     * 状态(0-已报名，1-待报价，2-洽商谈判，3-报价中，4-已定标，5-已淘汰)
     */
    public java.lang.Integer getSignStatus() {
        return signStatus;
    }

    /**
     * 状态(0-已报名，1-待报价，2-洽商谈判，3-报价中，4-已定标，5-已淘汰)
     */
    public void setSignStatus(java.lang.Integer signStatus) {
        this.signStatus = signStatus;
    }
    /**
     * 淘汰原因
     */
    public java.lang.String getOutReason() {
        return outReason;
    }

    /**
     * 淘汰原因
     */
    public void setOutReason(java.lang.String outReason) {
        this.outReason = outReason;
    }
    /**
     * 报名联系人
     */
    @ReferSerialTransfer(referCode="idm-employee")
    public Long getSignEmployeeId() {
        return signEmployeeId;
    }
    @ReferDeserialTransfer
    public void setSignEmployeeId(Long signEmployeeId) {
        this.signEmployeeId = signEmployeeId;
    }

    public String getSignEmployeeName() {
        return signEmployeeName;
    }

    public void setSignEmployeeName(String signEmployeeName) {
        this.signEmployeeName = signEmployeeName;
    }

    public String getSignEmployeeMobile() {
        return signEmployeeMobile;
    }

    public void setSignEmployeeMobile(String signEmployeeMobile) {
        this.signEmployeeMobile = signEmployeeMobile;
    }

    /**
     * 发票说明
     */
    public java.lang.String getInvoiceNote() {
        return invoiceNote;
    }

    /**
     * 发票说明
     */
    public void setInvoiceNote(java.lang.String invoiceNote) {
        this.invoiceNote = invoiceNote;
    }
    /**
     * 报名时间
     */
    public java.util.Date getSignTime() {
        return signTime;
    }

    /**
     * 报名时间
     */
    public void setSignTime(java.util.Date signTime) {
        this.signTime = signTime;
    }
    /**
     * 报价时间
     */
    public java.util.Date getSchemeTime() {
        return schemeTime;
    }

    /**
     * 报价时间
     */
    public void setSchemeTime(java.util.Date schemeTime) {
        this.schemeTime = schemeTime;
    }
    /**
     * 报名操作人
     */
    public java.lang.Long getSignId() {
        return signId;
    }

    /**
     * 报名操作人
     */
    public void setSignId(java.lang.Long signId) {
        this.signId = signId;
    }
    /**
     * 报名操作人名称
     */
    public String getSignName() {
        return signName;
    }

    public void setSignName(String signName) {
        this.signName = signName;
    }

    /**
     * 报价操作人
     */
    public Long getSchemeId() {
        return schemeId;
    }

    public void setSchemeId(Long schemeId) {
        this.schemeId = schemeId;
    }

    /**
     * 报价操作人名称
     */
    public java.lang.String getSchemeName() {
        return schemeName;
    }

    /**
     * 报价操作人名称
     */
    public void setSchemeName(java.lang.String schemeName) {
        this.schemeName = schemeName;
    }
    
}

==> ejc-supbid-api-3.0.1-20250811.031346-278-sources.jar: com/ejianc/business/supbid/notice/vo/SignVO.java <==
package com.ejianc.business.supbid.notice.vo;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;


/**
 * 报名实体
 * 
 * @author generator
 * 
 */
@ApiModel("报名实体")
public class SignVO{
    private static final long serialVersionUID = 1L;

    @ApiModelProperty("返回前段用的主键")
    private java.lang.Long sId;
    @ApiModelProperty("主表主键")
    private java.lang.Long noticeId;
    @ApiModelProperty("供应商来源主键")
    private java.lang.String sourceSupplierId;
    @ApiModelProperty("招标信息主键")
    private java.lang.String sourceId;
    @ApiModelProperty("状态(0-已报名，1-待报价，2-洽商谈判，3-报价中，4-已定标，5-已淘汰)")
    private java.lang.Integer signStatus;
    @ApiModelProperty("淘汰原因")
    private java.lang.String outReason;
    @ApiModelProperty("报名联系人")
    private java.lang.Long signEmployeeId;
    @ApiModelProperty("报名联系人名称")
    private java.lang.String signEmployeeName;
    @ApiModelProperty("报名联系人电话")
    private java.lang.String signEmployeeMobile;
    @ApiModelProperty("发票说明")
    private java.lang.String invoiceNote;
    @ApiModelProperty("报名时间")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private java.util.Date signTime;
    @ApiModelProperty("报价时间")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private java.util.Date schemeTime;
    @ApiModelProperty("报名操作人")
    private java.lang.Long signId;
    @ApiModelProperty("报名操作人名称")
    private java.lang.String signName;
    @ApiModelProperty("报价操作人")
    private java.lang.Long schemeId;
    @ApiModelProperty("报价操作人名称")
    private java.lang.String schemeName;
    @ApiModelProperty("租户主键")
    private java.lang.Long tenantId;
    private List<Long> attachIds = new ArrayList();

    private BigDecimal mnySubTender; //投标总价（无税）
    private java.lang.String mnySubTenderName; // 投标总价（无税）大写
    private BigDecimal taxMnySubTender; // 投标总价
    private java.lang.String taxMnySubTenderName; // 投标总价大写

    private java.lang.String priceType; // 新增单价确定方式
    private java.lang.String qualityPromise; // 质量承诺
    private java.lang.String safePromise; // 安全文明施工承诺
    private java.lang.String durationPromise; // 工期承诺
    private java.lang.String marginType; // 投标保证金形式
    private java.lang.String otherPromise; //其他承诺

    public BigDecimal getMnySubTender() {
        return mnySubTender;
    }

    public void setMnySubTender(BigDecimal mnySubTender) {
        this.mnySubTender = mnySubTender;
    }

    public String getMnySubTenderName() {
        return mnySubTenderName;
    }

    public void setMnySubTenderName(String mnySubTenderName) {
        this.mnySubTenderName = mnySubTenderName;
    }

    public BigDecimal getTaxMnySubTender() {
        return taxMnySubTender;
    }

    public void setTaxMnySubTender(BigDecimal taxMnySubTender) {
        this.taxMnySubTender = taxMnySubTender;
    }

    public String getTaxMnySubTenderName() {
        return taxMnySubTenderName;
    }

    public void setTaxMnySubTenderName(String taxMnySubTenderName) {
        this.taxMnySubTenderName = taxMnySubTenderName;
    }

    public String getPriceType() {
        return priceType;
    }

    public void setPriceType(String priceType) {
        this.priceType = priceType;
    }

    public String getQualityPromise() {
        return qualityPromise;
    }

    public void setQualityPromise(String qualityPromise) {
        this.qualityPromise = qualityPromise;
    }

    public String getSafePromise() {
        return safePromise;
    }

    public void setSafePromise(String safePromise) {
        this.safePromise = safePromise;
    }

    public String getDurationPromise() {
        return durationPromise;
    }

    public void setDurationPromise(String durationPromise) {
        this.durationPromise = durationPromise;
    }

    public String getMarginType() {
        return marginType;
    }

    public void setMarginType(String marginType) {
        this.marginType = marginType;
    }

    public String getOtherPromise() {
        return otherPromise;
    }

    public void setOtherPromise(String otherPromise) {
        this.otherPromise = otherPromise;
    }

    public List<Long> getAttachIds() {
        return attachIds;
    }

    public void setAttachIds(List<Long> attachIds) {
        this.attachIds = attachIds;
    }

    public Long getTenantId() {
        return tenantId;
    }

    public void setTenantId(Long tenantId) {
        this.tenantId = tenantId;
    }

    public Long getsId() {
        return sId;
    }

    public void setsId(Long sId) {
        this.sId = sId;
    }

    public String getSourceSupplierId() {
        return sourceSupplierId;
    }

    public void setSourceSupplierId(String sourceSupplierId) {
        this.sourceSupplierId = sourceSupplierId;
    }

    /**
     * 主表主键
     */
    public java.lang.Long getNoticeId() {
        return noticeId;
    }

    /**
     * 主表主键
     */
    public void setNoticeId(java.lang.Long noticeId) {
        this.noticeId = noticeId;
    }
    /**
     * 招标信息主键
     */
    public java.lang.String getSourceId() {
        return sourceId;
    }

    /**
     * 招标信息主键
     */
    public void setSourceId(java.lang.String sourceId) {
        this.sourceId = sourceId;
    }
    /**
     * 状态(0-已报名，1-待报价，2-洽商谈判，3-报价中，4-已定标，5-已淘汰)
     */
    public java.lang.Integer getSignStatus() {
        return signStatus;
    }

    /**
     * 状态(0-已报名，1-待报价，2-洽商谈判，3-报价中，4-已定标，5-已淘汰)
     */
    public void setSignStatus(java.lang.Integer signStatus) {
        this.signStatus = signStatus;
    }
    /**
     * 淘汰原因
     */
    public java.lang.String getOutReason() {
        return outReason;
    }

    /**
     * 淘汰原因
     */
    public void setOutReason(java.lang.String outReason) {
        this.outReason = outReason;
    }
    /**
     * 报名联系人
     */
    @ReferSerialTransfer(referCode="idm-employee")
    public Long getSignEmployeeId() {
        return signEmployeeId;
    }
    @ReferDeserialTransfer
    public void setSignEmployeeId(Long signEmployeeId) {
        this.signEmployeeId = signEmployeeId;
    }

    public String getSignEmployeeName() {
        return signEmployeeName;
    }

    public void setSignEmployeeName(String signEmployeeName) {
        this.signEmployeeName = signEmployeeName;
    }

    public String getSignEmployeeMobile() {
        return signEmployeeMobile;
    }

    public void setSignEmployeeMobile(String signEmployeeMobile) {
        this.signEmployeeMobile = signEmployeeMobile;
    }

    /**
     * 发票说明
     */
    public java.lang.String getInvoiceNote() {
        return invoiceNote;
    }

    /**
     * 发票说明
     */
    public void setInvoiceNote(java.lang.String invoiceNote) {
        this.invoiceNote = invoiceNote;
    }
    /**
     * 报名时间
     */
    public java.util.Date getSignTime() {
        return signTime;
    }

    /**
     * 报名时间
     */
    public void setSignTime(java.util.Date signTime) {
        this.signTime = signTime;
    }
    /**
     * 报价时间
     */
    public java.util.Date getSchemeTime() {
        return schemeTime;
    }

    /**
     * 报价时间
     */
    public void setSchemeTime(java.util.Date schemeTime) {
        this.schemeTime = schemeTime;
    }
    /**
     * 报名操作人
     */
    public java.lang.Long getSignId() {
        return signId;
    }

    /**
     * 报名操作人
     */
    public void setSignId(java.lang.Long signId) {
        this.signId = signId;
    }
    /**
     * 报名操作人名称
     */
    public String getSignName() {
        return signName;
    }

    public void setSignName(String signName) {
        this.signName = signName;
    }

    /**
     * 报价操作人
     */
    public Long getSchemeId() {
        return schemeId;
    }

    public void setSchemeId(Long schemeId) {
        this.schemeId = schemeId;
    }

    /**
     * 报价操作人名称
     */
    public java.lang.String getSchemeName() {
        return schemeName;
    }

    /**
     * 报价操作人名称
     */
    public void setSchemeName(java.lang.String schemeName) {
        this.schemeName = schemeName;
    }
    
}
